"use strict";
(() => {
  // src/constants.js
  var lang_dependencies = {
    javascript: "clike",
    actionscript: "javascript",
    apex: ["clike", "sql"],
    arduino: "cpp",
    aspnet: ["markup", "csharp"],
    birb: "clike",
    bison: "c",
    c: "clike",
    csharp: "clike",
    cpp: "c",
    cfscript: "clike",
    chaiscript: ["clike", "cpp"],
    cilkc: "c",
    cilkcpp: "cpp",
    coffeescript: "javascript",
    crystal: "ruby",
    "css-extras": "css",
    d: "clike",
    dart: "clike",
    django: "markup-templating",
    ejs: ["javascript", "markup-templating"],
    etlua: ["lua", "markup-templating"],
    erb: ["ruby", "markup-templating"],
    fsharp: "clike",
    "firestore-security-rules": "clike",
    flow: "javascript",
    ftl: "markup-templating",
    gml: "clike",
    glsl: "c",
    go: "clike",
    gradle: "clike",
    groovy: "clike",
    haml: "ruby",
    handlebars: "markup-templating",
    haxe: "clike",
    hlsl: "c",
    idris: "haskell",
    java: "clike",
    javadoc: ["markup", "java", "javadoclike"],
    jolie: "clike",
    jsdoc: ["javascript", "javadoclike", "typescript"],
    "js-extras": "javascript",
    json5: "json",
    jsonp: "json",
    "js-templates": "javascript",
    kotlin: "clike",
    latte: ["clike", "markup-templating", "php"],
    less: "css",
    lilypond: "scheme",
    liquid: "markup-templating",
    markdown: "markup",
    "markup-templating": "markup",
    mongodb: "javascript",
    n4js: "javascript",
    objectivec: "c",
    opencl: "c",
    parser: "markup",
    php: "markup-templating",
    phpdoc: ["php", "javadoclike"],
    "php-extras": "php",
    plsql: "sql",
    processing: "clike",
    protobuf: "clike",
    pug: ["markup", "javascript"],
    purebasic: "clike",
    purescript: "haskell",
    qsharp: "clike",
    qml: "javascript",
    qore: "clike",
    racket: "scheme",
    cshtml: ["markup", "csharp"],
    jsx: ["markup", "javascript"],
    tsx: ["jsx", "typescript"],
    reason: "clike",
    ruby: "clike",
    sass: "css",
    scss: "css",
    scala: "java",
    "shell-session": "bash",
    smarty: "markup-templating",
    solidity: "clike",
    soy: "markup-templating",
    sparql: "turtle",
    sqf: "clike",
    squirrel: "clike",
    stata: ["mata", "java", "python"],
    "t4-cs": ["t4-templating", "csharp"],
    "t4-vb": ["t4-templating", "vbnet"],
    tap: "yaml",
    tt2: ["clike", "markup-templating"],
    textile: "markup",
    twig: "markup-templating",
    typescript: "javascript",
    v: "clike",
    vala: "clike",
    vbnet: "basic",
    velocity: "markup",
    wiki: "markup",
    xeora: "markup",
    "xml-doc": "markup",
    xquery: "markup"
  };
  var lang_aliases = (
    /*aliases_placeholder[*/
    {
      html: "markup",
      xml: "markup",
      svg: "markup",
      mathml: "markup",
      ssml: "markup",
      atom: "markup",
      rss: "markup",
      js: "javascript",
      g4: "antlr4",
      ino: "arduino",
      "arm-asm": "armasm",
      art: "arturo",
      adoc: "asciidoc",
      avs: "avisynth",
      avdl: "avro-idl",
      gawk: "awk",
      sh: "bash",
      shell: "bash",
      shortcode: "bbcode",
      rbnf: "bnf",
      oscript: "bsl",
      cs: "csharp",
      dotnet: "csharp",
      cfc: "cfscript",
      "cilk-c": "cilkc",
      "cilk-cpp": "cilkcpp",
      cilk: "cilkcpp",
      coffee: "coffeescript",
      conc: "concurnas",
      jinja2: "django",
      "dns-zone": "dns-zone-file",
      dockerfile: "docker",
      gv: "dot",
      eta: "ejs",
      xlsx: "excel-formula",
      xls: "excel-formula",
      gamemakerlanguage: "gml",
      po: "gettext",
      gni: "gn",
      ld: "linker-script",
      "go-mod": "go-module",
      hbs: "handlebars",
      mustache: "handlebars",
      hs: "haskell",
      idr: "idris",
      gitignore: "ignore",
      hgignore: "ignore",
      npmignore: "ignore",
      webmanifest: "json",
      kt: "kotlin",
      kts: "kotlin",
      kum: "kumir",
      tex: "latex",
      context: "latex",
      ly: "lilypond",
      emacs: "lisp",
      elisp: "lisp",
      "emacs-lisp": "lisp",
      md: "markdown",
      moon: "moonscript",
      n4jsd: "n4js",
      nani: "naniscript",
      objc: "objectivec",
      qasm: "openqasm",
      objectpascal: "pascal",
      px: "pcaxis",
      pcode: "peoplecode",
      plantuml: "plant-uml",
      pq: "powerquery",
      mscript: "powerquery",
      pbfasm: "purebasic",
      purs: "purescript",
      py: "python",
      qs: "qsharp",
      rkt: "racket",
      razor: "cshtml",
      rpy: "renpy",
      res: "rescript",
      robot: "robotframework",
      rb: "ruby",
      "sh-session": "shell-session",
      shellsession: "shell-session",
      smlnj: "sml",
      sol: "solidity",
      sln: "solution-file",
      rq: "sparql",
      sclang: "supercollider",
      t4: "t4-cs",
      trickle: "tremor",
      troy: "tremor",
      trig: "turtle",
      ts: "typescript",
      tsconfig: "typoscript",
      uscript: "unrealscript",
      uc: "unrealscript",
      url: "uri",
      vb: "visual-basic",
      vba: "visual-basic",
      webidl: "web-idl",
      mathematica: "wolfram",
      nb: "wolfram",
      wl: "wolfram",
      xeoracube: "xeora",
      yml: "yaml"
    }
  );

  // src/core.js
  function autoloader(Prism2) {
    if (typeof Prism2 === "undefined" || typeof document === "undefined") {
      return;
    }
    let lang_data = {};
    let ignored_language = "none";
    let languages_path = "components/";
    let script = Prism2.util.currentScript();
    if (script) {
      let autoloaderFile = /\bplugins\/autoloader\/prism-autoloader\.(?:min\.)?js(?:\?[^\r\n/]*)?$/i;
      let prismFile = /(^|\/)[\w-]+\.(?:min\.)?js(?:\?[^\r\n/]*)?$/i;
      const src = script.src;
      if (autoloaderFile.test(src)) {
        languages_path = src.replace(autoloaderFile, "components/");
      } else if (prismFile.test(src)) {
        languages_path = src.replace(prismFile, "$1components/");
      }
    }
    let config = Prism2.plugins.autoloader = {
      languages_path,
      use_minified: true,
      loadLanguages,
      /** @type {Object<string, string | string[]>} */
      lang_dependencies: {},
      /** @type {Object<string, string>} */
      lang_aliases: {},
      /** @type {Object<string, string>} */
      lang_urls: {}
    };
    const getAlias = (lang) => {
      var _a;
      return (_a = { ...lang_aliases, ...config.lang_aliases }[lang]) != null ? _a : lang;
    };
    const addScript = (src, success, error) => {
      let s = document.createElement("script");
      s.src = src;
      s.async = true;
      s.onload = () => {
        document.body.removeChild(s);
        success && success();
      };
      s.onerror = () => {
        document.body.removeChild(s);
        error && error();
      };
      document.body.appendChild(s);
    };
    const getDependencies = (element) => {
      var _a, _b;
      let deps = ((_a = element.getAttribute("data-dependencies")) != null ? _a : "").trim();
      if (!deps) {
        let parent = element.parentElement;
        if (parent && parent.tagName.toLowerCase() === "pre") {
          deps = ((_b = parent.getAttribute("data-dependencies")) != null ? _b : "").trim();
        }
      }
      return deps ? deps.split(/\s*,\s*/g) : [];
    };
    const isLoaded = (lang) => {
      if (lang.includes("!")) {
        return false;
      }
      lang = getAlias(lang);
      if (lang in Prism2.languages) {
        return true;
      }
      let data = lang_data[lang];
      return data && !data.error && data.loading === false;
    };
    const getLanguagePath = (lang) => {
      var _a;
      return (_a = config.lang_urls[lang]) != null ? _a : "".concat(config.languages_path, "prism-").concat(lang).concat(config.use_minified ? ".min" : "", ".js");
    };
    function loadLanguages(languages, success, error) {
      if (typeof languages === "string") {
        languages = [languages];
      }
      let total = languages.length;
      let completed = 0;
      let failed = false;
      if (total === 0) {
        if (success) {
          setTimeout(success, 0);
        }
        return;
      }
      const successCallback = () => {
        if (failed) {
          return;
        }
        if (typeof languages === "string") {
          return;
        }
        completed++;
        if (completed === total) {
          success && success(languages);
        }
      };
      languages.forEach(function(lang) {
        loadLanguage(lang, successCallback, function() {
          if (failed) {
            return;
          }
          failed = true;
          error && error(lang);
        });
      });
    }
    function loadLanguage(lang, success, error) {
      const force = lang.includes("!");
      lang = lang.replace("!", "");
      lang = getAlias(lang);
      const load = () => {
        let data = lang_data[lang];
        if (!data) {
          data = lang_data[lang] = {
            callbacks: []
          };
        }
        data.callbacks.push({
          success,
          error
        });
        if (!force && isLoaded(lang)) {
          languageCallback(lang, "success");
        } else if (!force && data.error) {
          languageCallback(lang, "error");
        } else if (force || !data.loading) {
          data.loading = true;
          data.error = false;
          addScript(
            getLanguagePath(lang),
            () => {
              data.loading = false;
              languageCallback(lang, "success");
            },
            () => {
              data.loading = false;
              data.error = true;
              languageCallback(lang, "error");
            }
          );
        }
      };
      let dependencies = {
        ...lang_dependencies,
        ...config.lang_dependencies
      }[lang];
      if (dependencies && dependencies.length) {
        loadLanguages(dependencies, load, error);
      } else {
        load();
      }
    }
    function languageCallback(lang, type) {
      if (!lang_data[lang])
        return;
      const callbacks = lang_data[lang].callbacks;
      for (let i = 0, l = callbacks.length; i < l; i++) {
        const callback = callbacks[i][type];
        if (callback) {
          setTimeout(callback, 0);
        }
      }
      callbacks.length = 0;
    }
    Prism2.hooks.add("complete", (env) => {
      let element = env.element;
      let language = env.language;
      if (!element || !language || language === ignored_language) {
        return;
      }
      let deps = getDependencies(element);
      if (/^diff-./i.test(language)) {
        deps.push("diff");
        deps.push(language.substring("diff-".length));
      } else {
        deps.push(language);
      }
      if (!deps.every(isLoaded)) {
        loadLanguages(deps, () => element && Prism2.highlightElement(element));
      }
    });
  }

  // src/main.js
  autoloader(Prism);
})();
/**
 * Modified from prism-autoloader.js (https://github.com/PrismJS/prism/blob/master/plugins/autoloader/prism-autoloader.js)
 * Licensed under MIT, Copyright (c) 2012 Lea Verou
 *
 * Modified by Imken Luo, licensed under MIT
 * Copyright (c) 2023 Imken Luo
 *
 * @license MIT
 */
